@@ -3,7 +3,7 @@
  * Copyright (C) 2014 by Philippe Carriere
  *
  * This file is part of FFADO
- * FFADO = Free Firewire (pro-)audio drivers for linux
+ * FFADO = Free FireWire (pro-)audio drivers for Linux
  *
  * FFADO is based upon FreeBoB.
  *
@@ -28,6 +28,8 @@
 
 #include "libutil/ByteSwap.h"
 
+#include <sstream>
+
 namespace Dice {
 namespace Focusrite {
 
@@ -152,11 +154,11 @@ void Saffire56::Saffire56EAP::setupDestinations_mid() {
 // 192 kHz is not supported
 //
 void Saffire56::Saffire56EAP::setupSources_high() {
-    printMessage("High (192 kHz) sample rate not supported by Saffire Pro 40\n");
+    printMessage("High (192 kHz) sample rate not supported by Saffire Pro 56\n");
 }
 
 void Saffire56::Saffire56EAP::setupDestinations_high() {
-    printMessage("High (192 kHz) sample rate not supported by Saffire Pro 40\n");
+    printMessage("High (192 kHz) sample rate not supported by Saffire Pro 56\n");
 }
 
 /**
@@ -290,7 +292,7 @@ Saffire56::Saffire56EAP::setupDefaultRouterConfig_mid() {
  */
 void
 Saffire56::Saffire56EAP::setupDefaultRouterConfig_high() {
-    printMessage("High (192 kHz) sample rate not supported by Saffire Pro 40\n");
+    printMessage("High (192 kHz) sample rate not supported by Saffire Pro 56\n");
 }
 
 /**
