@@ -3,7 +3,7 @@
  * Copyright (C) 2012 by Philippe Carriere
  *
  * This file is part of FFADO
- * FFADO = Free Firewire (pro-)audio drivers for linux
+ * FFADO = Free FireWire (pro-)audio drivers for Linux
  *
  * FFADO is based upon FreeBoB.
  *
@@ -28,6 +28,8 @@
 
 #include "libutil/ByteSwap.h"
 
+#include <sstream>
+
 namespace Dice {
 namespace Focusrite {
 //
