@@ -2,7 +2,7 @@
  * Copyright (C) 2009 by Pieter Palmers
  *
  * This file is part of FFADO
- * FFADO = Free Firewire (pro-)audio drivers for linux
+ * FFADO = Free FireWire (pro-)audio drivers for Linux
  *
  * FFADO is based upon FreeBoB.
  *
@@ -27,6 +27,8 @@
 
 #include "libutil/ByteSwap.h"
 
+#include <sstream>
+
 namespace Dice {
 namespace Focusrite {
 
