@@ -2,7 +2,7 @@
  * Copyright (C) 2008 by Pieter Palmers
  *
  * This file is part of FFADO
- * FFADO = Free Firewire (pro-)audio drivers for linux
+ * FFADO = Free FireWire (pro-)audio drivers for Linux
  *
  * FFADO is based upon FreeBoB.
  *
@@ -24,7 +24,7 @@
 #ifndef __FFADO_UTIL_SERIALIZE_H__
 #define __FFADO_UTIL_SERIALIZE_H__
 
-#include "config.h"
+
 
 #if SERIALIZE_USE_EXPAT
     #include "serialize_expat.h"
