@@ -2,7 +2,7 @@
 #               2007-2009 by Arnold Krille
 #
 # This file is part of FFADO
-# FFADO = Free Firewire (pro-)audio drivers for linux
+# FFADO = Free FireWire (pro-)audio drivers for Linux
 #
 # FFADO is based upon FreeBoB.
 #
@@ -49,23 +49,116 @@ class StartDialog(QWidget):
         self.layout.setContentsMargins( 50, 10, 50, 10 )
         self.layout.addWidget(self.label, 0, 0, Qt.AlignHCenter|Qt.AlignBottom)
         self.layout.addWidget(self.button, 1, 0, Qt.AlignHCenter|Qt.AlignTop)
+ 
+class PreferencesDialog(QDialog):
+    def __init__(self, parent=None):
+        super(PreferencesDialog, self).__init__(parent)
+        self.setWindowTitle("Preferences")
+        self.settings = QtCore.QSettings(parent)
+        self.parent_window = parent
+        layout = QVBoxLayout(self)
+
+        # Show log window checkbox
+        self.log_checkbox = QCheckBox("Show log window", self)
+        show_log = self.settings.value("window/show_log", True, type=bool)
+        self.log_checkbox.setChecked(show_log)
+        layout.addWidget(self.log_checkbox)
+        self.log_checkbox.toggled.connect(self.on_log_checkbox_toggled)
+
+        # Load device settings on startup
+        self.load_settings_checkbox = QCheckBox("Load device settings on startup", self)
+        load_settings = self.settings.value("window/load_settings_on_startup", False, type=bool)
+        self.load_settings_checkbox.setChecked(load_settings)
+        layout.addWidget(self.load_settings_checkbox)
+        self.load_settings_checkbox.toggled.connect(self.on_load_settings_toggled)
+
+        # File path field and button
+        self.file_path_layout = QHBoxLayout()
+        self.file_path_edit = QLineEdit(self)
+        self.load_settings_label = QLabel("Choose path to saved file.", self)
+        self.file_path_layout.addWidget(self.load_settings_label)
+        saved_path = self.settings.value("window/device_settings_path", "", type=str)
+        self.file_path_edit.setText(saved_path)
+        self.file_dialog_btn = QPushButton("...", self)
+        self.file_dialog_btn.clicked.connect(self.select_file_dialog)
+        self.file_path_layout.addWidget(self.file_path_edit)
+        self.file_path_layout.addWidget(self.file_dialog_btn)
+        layout.addLayout(self.file_path_layout)
+
+        # Show/hide file path widgets based on checkbox
+        self.load_settings_label.setVisible(load_settings)
+        self.file_path_edit.setVisible(load_settings)
+        self.file_dialog_btn.setVisible(load_settings) 
+
+        buttonBox = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel, self)
+        buttonBox.accepted.connect(self.accept)
+        buttonBox.rejected.connect(self.reject)
+        layout.addWidget(buttonBox)
+
+    def get_log_checkbox_state(self):
+        return self.log_checkbox.isChecked()
+
+    def on_log_checkbox_toggled(self, checked):
+        # Update dock visibility immediately
+        if self.parent_window is not None:
+            self.parent_window.logger_dock.setVisible(checked)
+            
+    def on_load_settings_toggled(self, checked):
+        self.load_settings_label.setVisible(checked)
+        self.file_path_edit.setVisible(checked)
+        self.file_dialog_btn.setVisible(checked)
+
+    def select_file_dialog(self):
+        path, _ = QFileDialog.getOpenFileName(self, "Select Device Settings File")
+        if path:
+            self.file_path_edit.setText(path)
+
+    def get_load_settings_state(self):
+        return self.load_settings_checkbox.isChecked()
+
+    def get_device_settings_path(self):
+        return self.file_path_edit.text() 
+
+    def accept(self):
+        self.settings.setValue("window/show_log", self.log_checkbox.isChecked())
+        super(PreferencesDialog, self).accept()
 
 class FFADOWindow(QMainWindow):
     def __init__(self, parent):
         QMainWindow.__init__(self, parent)
 
         self.textlogger = QTextLogger(self)
-        dock = QDockWidget("Log Messages",self)
-        dock.setWidget(self.textlogger.textedit)
+        self.logger_dock = QDockWidget("Log Messages",self)
+        self.logger_dock.setWidget(self.textlogger.textedit)
         logging.getLogger('').addHandler(self.textlogger)
-        self.addDockWidget(Qt.BottomDockWidgetArea, dock)
+        self.addDockWidget(Qt.BottomDockWidgetArea, self.logger_dock)
 
         self.statuslogger = QStatusLogger(self, self.statusBar(), 20)
         logging.getLogger('').addHandler(self.statuslogger)
 
+        self.settings = QtCore.QSettings(self)
+ 
+        # Show/hide log dock based on settings
+        show_log = self.settings.value("window/show_log", True, type=bool)
+        self.logger_dock.setVisible(show_log)
+
+        # Restore window geometry and position
+        geometry = self.settings.value("window/geometry")
+        if geometry is not None:
+            self.restoreGeometry(geometry)
+        window_state = self.settings.value("window/state")
+        if window_state is not None:
+            self.restoreState(window_state)
+
         self.manager = PanelManager(self)
         self.manager.connectionLost.connect(self.connectToDBUS)
 
+        # Load device settings on startup if enabled and path is set
+        load_settings = self.settings.value("window/load_settings_on_startup", False, type=bool)
+        device_settings_path = self.settings.value("window/device_settings_path", "", type=str)
+        if load_settings and device_settings_path:
+            self.manager.readSettings(device_settings_path)
+
         filemenu = self.menuBar().addMenu("&File")
         self.openaction = QAction(QIcon.fromTheme("document-open"),"&Open", self)
         self.openaction.setShortcut(self.tr("Ctrl+O"))
@@ -84,6 +177,12 @@ class FFADOWindow(QMainWindow):
 
         self.editmenu = self.menuBar().addMenu("&View")
 
+        self.setPreferencesAction = QtWidgets.QAction(parent)
+        self.setPreferencesAction.setText("Preferences")
+        self.setPreferencesAction.setObjectName("setPreferencesAction")
+        self.setPreferencesAction.triggered.connect(self.showPreferencesDialog)
+        self.editmenu.addAction(self.setPreferencesAction)
+
         self.thememenu = self.editmenu.addMenu("Theme")
         themes = QStyleFactory.keys()
         self.menuTheme = {}
@@ -99,6 +198,23 @@ class FFADOWindow(QMainWindow):
             self.menuTheme[theme].triggered.connect(self.switchTheme )
             self.thememenu.addAction( self.menuTheme[theme] )
 
+        conftheme = self.settings.value("window/theme", "ukui-dark")
+        contains = False
+        for theme in self.menuTheme:
+            if theme.__str__() == conftheme:
+                contains = True
+                break
+        if contains:
+            for theme in self.menuTheme:
+                if theme.__str__() != conftheme:
+                    self.menuTheme[theme].setChecked(False)
+                    self.menuTheme[theme].setDisabled(False)
+            for theme in self.menuTheme:
+                if theme.__str__() == conftheme:
+                    self.menuTheme[theme].setDisabled(True)
+                    QApplication.setStyle(QStyleFactory.create(theme))
+                    self.settings.setValue("window/theme", theme.__str__())
+
         self.updateaction = QAction(QIcon.fromTheme("view-refresh"),"&Update Mixer Panels", self)
         self.updateaction.setEnabled(False)
         self.updateaction.triggered.connect(self.manager.updatePanels)
@@ -120,6 +236,18 @@ class FFADOWindow(QMainWindow):
         log.info( "Starting up" )
 
         QTimer.singleShot( 1, self.tryStartDBUSServer )
+        QTimer.singleShot( 2 * POLL_SLEEP_TIME_MSEC, self.loadSettings )
+
+    def loadSettings(self):
+        # Load device settings on startup if enabled and path is set
+        load_settings = self.settings.value("window/load_settings_on_startup", False, type=bool)
+        device_settings_path = self.settings.value("window/device_settings_path", "", type=str)
+        if load_settings and device_settings_path:
+            self.manager.readSettings(device_settings_path) 
+
+    def showPreferencesDialog(self):
+        dialog = PreferencesDialog(self)
+        dialog.exec_()
 
     def __del__(self):
         log.info("__del__")
@@ -135,8 +263,12 @@ class FFADOWindow(QMainWindow):
             if self.menuTheme[theme].isChecked() :
                 self.menuTheme[theme].setDisabled(True)
                 QApplication.setStyle(QStyleFactory.create(theme))
+                self.settings.setValue("window/theme", theme.__str__())
 
     def closeEvent(self, event):
+        # Save window geometry and state
+        self.settings.setValue("window/geometry", self.saveGeometry())
+        self.settings.setValue("window/state", self.saveState())        
         log.info("closeEvent()")
         event.accept()
 
@@ -160,7 +292,7 @@ class FFADOWindow(QMainWindow):
         except dbus.DBusException as ex:
             if hasattr(self, "retry"):
                 self.retry.setEnabled(False)
-            subprocess.Popen(['ffado-dbus-server', '-v3']).pid
+            subprocess.Popen(['ffado-dbus-server', '-v3'], close_fds=True).pid
             QTimer.singleShot(5000, self.connectToDBUS)
 
     def setupDeviceManager(self):
@@ -173,13 +305,13 @@ class FFADOWindow(QMainWindow):
 
     def aboutFFADO(self):
         QMessageBox.about( self, "About FFADO", """
-<h1>ffado.org</h1>
+<h1><a href="http://ffado.org">ffado.org</a></h1>
 
 <p>{ffado_version}</p>
 
-<p>FFADO is the new approach to have firewire audio on linux.</p>
+<p><a href="http://ffado.org">FFADO</a> is the new approach to have FireWire audio on Linux.</p>
 
-        <p>&copy; 2006-2018 by the FFADO developers<br />ffado is licensed under the GPLv3, for the full license text see <a href="http://www.gnu.org/licenses/">www.gnu.org/licenses</a> or the LICENSE.* files shipped with ffado.</p>
+        <p>&copy; 2006-2025 by the FFADO developers<br />ffado is licensed under the GPLv3, for the full license text see <a href="http://www.gnu.org/licenses/">www.gnu.org/licenses</a> or the LICENSE.* files shipped with ffado.</p>
 
 <p>FFADO developers are:<ul>
 <li>Pieter Palmers
@@ -193,6 +325,7 @@ with contributions from:<ul>
 <li>Adrian Knoth
 <li>Stefan Richter
 <li>Jano Svitok
+<li>Pander Musubi
 </ul>
         """.format(ffado_version=get_ffado_version(), thisyear=datetime.datetime.now().year))
 
@@ -202,7 +335,7 @@ def get_ffado_version():
         lib = ctypes.cdll.LoadLibrary('libffado.so')
         func = ctypes.CFUNCTYPE(ctypes.c_char_p)
         ffado_get_version = func(('ffado_get_version', lib))
-        return ffado_get_version()
+        return str(ffado_get_version())
     except:
         return "libffado"
 
