@@ -4,7 +4,7 @@
 #               2013 by Philippe Carriere
 #
 # This file is part of FFADO
-# FFADO = Free Firewire (pro-)audio drivers for linux
+# FFADO = Free FireWire (pro-)audio drivers for Linux
 #
 # FFADO is based upon FreeBoB.
 #
@@ -245,10 +245,16 @@ class PanelManager(QWidget):
 
         # check whether this has already been registered at ffado.org
         if not ffado.config.bypassdbus:
-            reg = ffado_registration(FFADO_VERSION, int(guid, 16),
-                                         vendorId, modelId,
-                                         vendorName, modelName)
-            reg.check_for_registration()
+            # As of June 2020, don't offer the registration option as the
+            # statistics are no longer useful.  Coincidently, a move to
+            # different website infrastructure June 2020 would necessitate
+            # some work to reimplement the interfaces used by the
+            # registration process, which doesn't seem worthwhile.
+            #
+            # reg = ffado_registration(FFADO_VERSION, int(guid, 16),
+            #                              vendorId, modelId,
+            #                              vendorName, modelName)
+            # reg.check_for_registration()
 
             # The MOTU devices use unitVersion to differentiate models.  For
             # the moment though we don't need to know precisely which model
@@ -522,8 +528,13 @@ class PanelManager(QWidget):
           f.write(s)
         f.close()
 
-    def readSettings(self):
-        readfilename = QFileDialog.getOpenFileName(self, 'Open File', os.getenv('HOME'))
+    def readSettings(self, path):
+        if path == None or os.path.exists(path) == False:
+            # use the file dialog to get a file name
+            readfilename = QFileDialog.getOpenFileName(self, 'Open File', os.getenv('HOME'))
+        else:
+            readfilename = path
+            
         if isinstance(readfilename, tuple): # newer PyQt5
             readfilename = readfilename[0]
         try:
@@ -602,7 +613,7 @@ class PanelManager(QWidget):
               log.debug("Device %s not present; settings ignored" % guid)
 
           del stringDev[:]
-          del readString[idxb:idxe]
+          del readString[idxb:idxe+1]
           nd -= 1
    
 # vim: et
